@@ -1,12 +1,18 @@
 # coding: utf-8
 from abc import ABC, abstractmethod
 import numbers
-
+from typing import Optional
+from ..helper import is_iterable
 # region Interface
 
 
 class IRule(ABC):
-    """Abstract Interface Class for rules"""
+    """
+    Abstract Interface Class for rules
+
+    See Also:
+        :doc:`/source/general/rules`
+    """
 
     def __init__(self, key: str, name: str, value: object, raise_errors: bool, originator: object):
         """
@@ -47,9 +53,23 @@ class IRule(ABC):
         '''Gets attrib field and value are valid'''
     # endregion Abstract Methods
 
-    def _get_type_error_msg(self, arg: object, arg_name: str, expected_type: str) -> str:
-        result = f"Argument Error: '{arg_name}' is expecting type of '{expected_type}'. Got type of '{type(arg).__name__}'"
-        return result
+    def _get_type_error_msg(self, arg: Optional[object] = None, arg_name: Optional[str] = None, expected_type: Optional[str] = None) -> str:
+        _arg = self.field_value if arg is None else arg
+        _arg_name = self.key if arg_name is None else arg_name
+        if expected_type:
+            msg = f"Argument Error: '{_arg_name}' is expecting type of '{expected_type}'. Got type of '{type(_arg).__name__}'"
+        else:
+            msg = f"Argument Error: '{_arg_name}' is not expecting '{type(_arg).__name__}'"
+        return msg
+
+    def _get_not_type_error_msg(self, arg: Optional[object] = None, arg_name: Optional[str] = None, not_type: Optional[str] = None) -> str:
+        _arg = self.field_value if arg is None else arg
+        _arg_name = self.key if arg_name is None else arg_name
+        if not_type:
+            msg = f"Argument Error: '{_arg_name}' is expecting non '{not_type}'. Got type of '{type(_arg).__name__}'"
+        else:
+            msg = f"Argument Error: '{_arg_name}' is expecting non '{type(_arg).__name__}'."
+        return msg
     # region Properties
 
     @property
@@ -274,8 +294,7 @@ class RuleInt(IRule):
         # print(int(False)) 0
         if not isinstance(self.field_value, int) or isinstance(self.field_value, bool):
             if self.raise_errors:
-                raise TypeError(self._get_type_error_msg(
-                    self.field_value, self.key, 'int'))
+                raise TypeError(self._get_type_error_msg(expected_type='int'))
             return False
         return True
 
@@ -676,15 +695,63 @@ class RuleBool(IRule):
         Validates that value to assign is a bool
 
         Raises:
-            ValueError: If ``raise_errors`` is ``True`` and ``field_value`` is not instance of bool.
+            TypeError: If ``raise_errors`` is ``True`` and ``field_value`` is not instance of bool.
 
         Returns:
             bool: ``True`` if ``field_value`` is a bool; Otherwise, ``False``.
         """
         if not isinstance(self.field_value, bool):
             if self.raise_errors:
-                raise TypeError(self._get_type_error_msg(
-                    self.field_value, self.key, 'bool'))
+                raise TypeError(self._get_type_error_msg(expected_type='bool'))
             return False
         return True
 # endregion boolean
+
+# region Iterable
+
+
+class RuleIterable(IRule):
+    """
+     Rule that matched only if value is iterable such as list, tuple, set.
+    """
+
+    def validate(self) -> bool:
+        """
+        Validates that value to assign is iterable
+
+        Raises:
+            TypeError: If ``raise_errors`` is ``True`` and ``field_value`` is not iterable.
+
+        Returns:
+            bool: ``True`` if ``field_value`` is a iterable; Otherwise, ``False``.
+        """
+        if not is_iterable(self.field_value):
+            if self.raise_errors:
+                raise TypeError(self._get_type_error_msg(expected_type="iterable"))
+            return False
+        return True
+
+
+class RuleNotIterable(IRule):
+    """
+     Rule that matched only if value is not iterable.
+    """
+
+    def validate(self) -> bool:
+        """
+        Validates that value to assign is not iterable
+
+        Raises:
+            TypeError: If ``raise_errors`` is ``True`` and ``field_value`` is iterable.
+
+        Returns:
+            bool: ``True`` if ``field_value`` is a not iterable; Otherwise, ``False``.
+        """
+        if is_iterable(self.field_value):
+            if self.raise_errors:
+                raise TypeError(self._get_not_type_error_msg(not_type="iterable"))
+            return False
+        return True
+    
+    
+# endregion Iterable
